@@ -306,3 +306,20 @@ class ApiObjectTest(unittest.TestCase):
             m.patch(url, text=expected)
             actual = self.ao.patch()
             assert actual == expected
+
+    # We're not testing an exhaustive set of suffix patterns here because
+    # that is already being done by the ApiObject unit tests. Just
+    # get() and get(something) is enough.
+    def test_wrapped_get(self):
+        with requests_mock.Mocker() as m:
+            url = self.awrapper.api.compute_url()
+            expected = 'unit test wrapped get result'
+            m.get(url, text=expected, complete_qs=True)
+            actual = self.awrapper.get()
+            assert actual == expected
+        with requests_mock.Mocker() as m:
+            suffix = 'some/where/random'
+            url = self.awrapper.api.compute_url(suffix)
+            m.get(url, text=expected, complete_qs=True)
+            actual = self.awrapper.get(suffix)
+            assert actual == expected
